/* Chris Sevilleja https://scotch.io/tutorials/google-material-design-input-boxes-in-css3*/

.group {
    position: relative;
    margin-bottom: 7px;
}
.group input {
    font-size: 18px;
    padding: 10px 0;
    display: block;
    width: 300px;
    border: none;
    border-bottom: 1px solid var(--primary, #00695C);
}
.group input:focus {
    outline: none;
}

.group input:focus~ .bar:before, input:focus~ .bar:after {
    width: 50%;
}

.group input:focus~ label, .group input:valid~ label, .group input.valid~ label {
    top: -20px;
    font-size: 14px;
    color: var(--primary, #00695C);
}

.group input:focus~ .highlight {
    -webkit-animation: inputHighlighter 0.3s ease;
    animation: inputHighlighter 0.3s ease;
}

.group label {
    color: #999;
    font-size: 18px;
    font-weight: normal;
    position: absolute;
    pointer-events: none;
    left: 5px;
    top: 10px;
    transition: 0.2s ease all;
    -moz-transition: 0.2s ease all;
    -webkit-transition: 0.2s ease all;
}

.group .bar {
    position: relative;
    display: block;
    width: 300px;
}
.group .bar:before, .group .bar:after {
    content: '';
    height: 2px;
    width: 0;
    bottom: 1px;
    position: absolute;
    background: var(--primary, #00695C);
    transition: 0.2s ease all;
    -moz-transition: 0.2s ease all;
    -webkit-transition: 0.2s ease all;
}
.group .bar:before {
    left: 50%;
}
.group .bar:after {
    right: 50%;
}

.group .highlight {
    position: absolute;
    height: 60%;
    width: 100px;
    top: 25%;
    left: 0;
    pointer-events: none;
    opacity: 0.5;
}

@-webkit-keyframes inputHighlighter {
    from {
        background: var(--primary, #00695C);
    }
    to {
        width: 0;
        background: transparent;
    }
}
@keyframes inputHighlighter {
    from {
        background: var(--primary, #00695C);
    }
    to {
        width: 0;
        background: transparent;
    }
}
